<?php
namespace App\Helpers\Traits;

/**
 * This trait provides some helper methods for dealing with Book names, titles, etc.
 *
 * BookTitleHelperTrait.php
 *
 * @author: Leonard Smith <leonard@acornwebconsultants.com>
 * Date: 5/4/21
 * Time: 11:13 AM
 */
trait BookTitleHelperTrait
{
    /**
     * @param string $bookTitle
     * @return string
     */
    protected function prepareBookName(string $bookTitle) : string
    {
        $parts = $this->parseBookTitle($bookTitle);
        return !isset($parts[1]) ? ucfirst($parts[0]) : $parts[0] . " " . ucfirst($parts[1]);
    }

    /**
     * @param string $bookTitle
     * @return string
     */
    protected function prepareBookId(string $bookTitle) : string
    {
        $parts = $this->parseBookTitle($bookTitle);
        return !isset($parts[1]) ? strtolower($parts[0]) : $parts[0] . " " . strtolower($parts[1]);
    }

    /**
     * @param string $bookTitle
     * @return array|string[]
     */
    protected function parseBookTitle(string $bookTitle) : array
    {
        if (is_numeric(substr($bookTitle, 0, 1))) {
            return [ substr($bookTitle, 0, 1),  ltrim(substr($bookTitle, 1)) ];
        } else {
            return [ $bookTitle ];
        }
    }
}
