<?php

namespace App\JsonApi\Verses;

use Neomerx\JsonApi\Schema\SchemaProvider;

class Schema extends SchemaProvider
{

    /**
     * @var string
     */
    protected $resourceType = 'verses';

    /**
     * @param \App\Verse $resource
     *      the domain record being serialized.
     * @return string
     */
    public function getId($resource)
    {
        return (string) $resource->getRouteKey();
    }

    /**
     * @param \App\Verse $resource
     *      the domain record being serialized.
     * @return array
     */
    public function getAttributes($resource)
    {
        return [
            'name' => $resource->name,
            'reference' => $resource->reference,
            'ulb-text' => $resource->ulb_text,
            'greek-text' => $resource->greek_text,
            'created-at' => $resource->created_at->toAtomString(),
            'updated-at' => $resource->updated_at->toAtomString(),
        ];
    }

    /**
     * @param object $resource
     * @param bool $isPrimary
     * @param array $includeRelationships
     * @return array|\bool[][]
     */
    public function getRelationships($resource, $isPrimary, array $includeRelationships)
    {
        return [
            'words' => [
                self::SHOW_SELF => true,
                self::SHOW_RELATED => true,
                self::SHOW_DATA => isset($includeRelationships['words']),
                self::DATA => function () use ($resource) {
                    return $resource->words;
                },
            ]
        ];
    }
}
