<?php

namespace App;

use App\Helpers\Traits\BookTitleHelperTrait;
use Illuminate\Database\Eloquent\Model;

class Verse extends Model
{
    use BookTitleHelperTrait;

    public $incrementing = false;

    public $fillable = [
        'id',
        'name',
        'ulb_text',
        'greek_text',
    ];

    public $visible = [
        'name',
        'reference',
        'ulb_text',
        'greek_text',
    ];

    /**
     * @return \Illuminate\Database\Eloquent\Relations\BelongsTo
     */
    public function chapter()
    {
        return $this->belongsTo(Chapter::class);
    }

    /**
     * @return \Illuminate\Database\Eloquent\Relations\HasMany
     */
    public function words()
    {
        return $this->hasMany(Word::class);
    }

    public function getReferenceAttribute()
    {
        $parts = explode('-', $this->id);

        return $this->prepareBookName(ucfirst($parts[0])) . ' ' . $parts[1] . ':' . $parts[2];
    }
}
