<?php
namespace Tests\Unit;

use App\Helpers\Traits\BookTitleHelperTrait;
use Tests\TestCase;

class BookTitleHelperTraitTest extends TestCase
{
    public function testThatParseBookTitleHandlesNumberedBooksCorrectly()
    {
        $handler = new BookTitleTester();

        $reflection_class = new \ReflectionClass(BookTitleTester::class);
        $method = $reflection_class->getMethod('parseBookTitle');
        $method->setAccessible(true);

        $result = $method->invoke($handler, '1corinthians');
        $this->assertEquals(['1', 'corinthians'], $result);

        $result = $method->invoke($handler, 'john');
        $this->assertEquals(['john'], $result);
    }

    public function testThatPrepareBookNameReturnsProperlyFormattedName()
    {
        $handler = new BookTitleTester();

        $reflection_class = new \ReflectionClass(BookTitleTester::class);
        $method = $reflection_class->getMethod('prepareBookName');
        $method->setAccessible(true);

        $result = $method->invoke($handler, '1corinthians');
        $this->assertEquals('1 Corinthians', $result);

        $result = $method->invoke($handler, 'john');
        $this->assertEquals('John', $result);
    }

    public function testThatWhitespaceBetweenNumberAndTextDoesNotBreakCapitalization()
    {
        $handler = new BookTitleTester();

        $reflection_class = new \ReflectionClass(BookTitleTester::class);
        $method = $reflection_class->getMethod('prepareBookName');
        $method->setAccessible(true);

        $result = $method->invoke($handler, '1 corinthians');
        $this->assertEquals('1 Corinthians', $result);
    }
}

class BookTitleTester
{
    use BookTitleHelperTrait;
}
